@@ -29,10 +29,11 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                            '-frecord-gcc-switches -fdiagnostics-color=never '
-                            '-fwrapv -std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                            '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
+                            '-ffat-lto-objects -g -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -40,23 +41,27 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs',
+                             '-Wl,-z,pack-relative-relocs -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
-                "'--docdir=/usr/share/doc/python-3.10.13' "
-                "'--htmldir=/usr/share/doc/python-3.10.13/html' "
+                "'--datarootdir=/usr/share' "
+                "'--docdir=/usr/share/doc/python-3.10.18_p2' "
+                "'--htmldir=/usr/share/doc/python-3.10.18_p2/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
-                "'--mandir=/usr/share/man' '--with-computed-gotos' "
-                "'--with-dbmliborder=gdbm' '--with-libc=' "
-                "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--without-lto' '--with-system-expat' '--with-system-ffi' "
+                "'--mandir=/usr/share/man' '--with-dbmliborder=gdbm' "
+                "'--with-libc=' '--enable-loadable-sqlite-extensions' "
+                "'--without-ensurepip' '--without-lto' '--with-system-expat' "
+                "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' "
+                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' 'CFLAGS=' 'LDFLAGS=' "
                 "'CPPFLAGS= -I/usr/include/ncursesw' "
@@ -64,8 +69,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13/coverage.info',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13/lcov-report',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18/coverage.info',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
@@ -546,15 +551,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.10',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -663,10 +667,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O3 '
-                             '-pipe -march=ivybridge -mtune=skylake '
-                             '-frecord-gcc-switches -fdiagnostics-color=never '
-                             '-fwrapv -std=c99 -Wextra -Wno-unused-result '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                             '-pipe -march=x86-64-v3 -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                             '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                             '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
@@ -675,33 +681,43 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                     '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
-                     '-std=c99 -Wextra -Wno-unused-result '
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                     '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                     '-ffat-lto-objects -flto -fuse-linker-plugin '
+                     '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O3 -pipe '
-                   '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -fwrapv -std=c99 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                    '-Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                      '-Werror=odr -Werror=lto-type-mismatch '
+                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-ffat-lto-objects -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O3 -pipe '
-                        '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                        '-fdiagnostics-color=never -fwrapv -std=c99 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
+                        '-march=x86-64-v3 -Werror=odr '
+                        '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                        '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -g -std=c99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -715,7 +731,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -757,10 +773,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -773,10 +789,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': './Tools/scripts/update_file.py',
- 'USE_COMPUTED_GOTOS': 1,
+ 'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.10',
  'WHEEL_PKG_DIR': '/usr/lib/python/ensurepip',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -788,8 +804,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.10.13/work/Python-3.10.13',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.10.18_p2/work/Python-3.10.18',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
